(about)=

# About `vak`

The `vak` library has two main goals:

1. make it easier for researchers studying animal vocalizations to
   apply neural network algorithms to their data
2. provide a common framework for benchmarking neural
   network algorithms on tasks related to animal vocalizations

Neural network algorithms in `vak` help answer questions about *vocal behavior*. 
We use the term "vocal behavior" to encompass related research areas 
including *animal communication* [^cite_Beecher2020], 
*cultural evolution* [^cite_YoungbloodLahti2018], 
and *vocal learning* [^cite_wikipedia] [^cite_wir2019].
Models in the `vak` library 
include deep learning algorithms developed for bioacoustics [^cite_Stowell2022], 
but are designed specifically for computational studies of vocal behavior [^cite_SainburgGentner2020].

The library was developed by
[David Nicholson](https://nicholdav.info/)
and
[Yarden Cohen](https://yardencsgithub.github.io/)
for experiments assessing performance of
[TweetyNet](https://github.com/yardencsGitHub/tweetynet),
a neural network that automates annotation of birdsong,
by segmenting spectograms into the units of song, called syllables.

[^cite_Beecher2020]: Beecher, Michael D. 
   “Animal Communication.” 
   In Oxford Research Encyclopedia of Psychology. 
   Oxford University Press, 2020. <https://doi.org/10.1093/acrefore/9780190236557.013.646>.  
   <https://oxfordre.com/psychology/view/10.1093/acrefore/9780190236557.001.0001/acrefore-9780190236557-e-646>.

[^cite_YoungbloodLahti2018]: Youngblood, Mason, and David Lahti. 
   “A Bibliometric Analysis of the Interdisciplinary Field of Cultural Evolution.” 
   Palgrave Communications 4, no. 1 (December 2018): 120. <https://doi.org/10.1057/s41599-018-0175-8>.
   <https://www.nature.com/articles/s41599-018-0175-8>.

[^cite_wikipedia]: <https://en.wikipedia.org/wiki/Vocal_learning>

[^cite_wir2019]: Wirthlin M, Chang EF, Knörnschild M, Krubitzer LA, Mello CV, Miller CT,
    Pfenning AR, Vernes SC, Tchernichovski O, Yartsev MM.
    "A modular approach to vocal learning: disentangling the diversity of
    a complex behavioral trait." Neuron. 2019 Oct 9;104(1):87-99.
    <https://www.sciencedirect.com/science/article/pii/S0896627319308396>


[^cite_Stowell2022]: Stowell, Dan. 
  “Computational Bioacoustics with Deep Learning: A Review and Roadmap,” 2022, 46.
  <https://peerj.com/articles/13152/>

[^cite_SainburgGentner2020]: Sainburg, Tim, and Timothy Q. Gentner. 
   “Toward a Computational Neuroethology of Vocal Communication: 
   From Bioacoustics to Neurophysiology, Emerging Tools and Future Directions.” 
   Frontiers in Behavioral Neuroscience 15 (December 20, 2021): 811737. https://doi.org/10.3389/fnbeh.2021.811737.
   <https://www.frontiersin.org/articles/10.3389/fnbeh.2021.811737/full>
